#include "ModbusDataPOC.h"


std::string ModbusDataPOC::getStatusMessage(unsigned short statusID)
{
    switch (statusID)
    {
    case 1:
        return "Breaker off (without realeasing)";
    case 2:
        return "Breaker normal (on)";
    case 3:
        return "Breaker released (off)";
    case 4:
        return "Breaker released (Lever on and blocked)";
    default:
        return "Status unknown";
    }
}



ModbusDataPOC::ModbusDataPOC(const unsigned int id) : ModbusDataInterface(id){
	
//Store Modbus reading registers
	//Identification
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Manufacturer,									0x0002,		Access::R);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Ordernumber,								0x0003, 20, Access::R);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Seriesnumber,								0x000D, 16, Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Hardware_Version,								0x0015,		Access::R);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Software_Version,							0x0016, 4,	Access::R);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Plant_identification_code,					0x001D, 32, Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Installation_site,							0x002D, 22, Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Installation_date,							0x0038, 16, Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_Firmware_Applicationcontroller,			0x0045, 10, Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Market,										0x005E,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Main_device_rated_current,					0x005F,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Tripping_curve_characteristic,				0x0060,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Installation_place_fuse,						0x0062,		Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_Ident_MLFB_fuse,									0x0063, 20, Access::RW);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_Hardware_Electronics,							0x006D,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Ident_rated_current_melting_part,					0x006E,		Access::RW);

	//IP
    modbusParamString.emplace_back(ModbusRegister::POC_IP_Ethernet_MAC,									0x0200, 6,	Access::R);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Status_DHCP,										0x0203,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_SNTP_server_ip,									0x0205,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_SNTP_client_mode,								0x0207,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Status_firewall,									0x0209,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_port_number,										0x020D,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Static_IP,										0x020F,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Subnetmask,										0x0211,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Gateway,											0x029D,		Access::RW);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Current_IP,										0x029F,		Access::R);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Current_Subnet,									0x02A1,		Access::R);
    modbusParamU32.emplace_back(ModbusRegister::POC_IP_Current_Gateway,									0x02A3,		Access::R);

	//Bluetooth
    modbusParamU16.emplace_back(ModbusRegister::POC_BT_Status,											0x0301,		Access::R);
    modbusParamS16.emplace_back(ModbusRegister::POC_BT_send_power,										0x0302,		Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_BT_device_address,								0x0303, 6,	Access::R);
    modbusParamU32.emplace_back(ModbusRegister::POC_BT_passkey,											0x0306,		Access::RW);

	//Radio
    modbusParamU32.emplace_back(ModbusRegister::POC_Radio_Date_time_utc,								0x02A3,		Access::RW);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_1,								0x0402,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_2,								0x0403,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_3,								0x0404,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_4,								0x0405,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_5,								0x0406,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_6,								0x0407,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_7,								0x0408,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_8,								0x0409,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_9,								0x040A,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_10,								0x040B,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_11,								0x040C,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_12,								0x040D,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_13,								0x040E,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_14,								0x040F,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_15,								0x0410,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_16,								0x0411,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_17,								0x0412,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_18,								0x0413,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_19,								0x0414,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_20,								0x0415,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_21,								0x0416,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_22,								0x0417,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_23,								0x0418,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Paring_status_24,								0x0419,		Access::R);
    modbusParamS16.emplace_back(ModbusRegister::POC_Radio_transmit_power,								0x041A,		Access::RW);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_1,								0x041B,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_2,								0x041C,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_3,								0x041D,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_4,								0x041E,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_5,								0x041F,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_6,								0x0420,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_7,								0x0421,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_8,								0x0422,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_9,								0x0423,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_10,								0x0424,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_11,								0x0425,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_12,								0x0426,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_13,								0x0427,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_14,								0x0428,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_15,								0x0429,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_16,								0x042A,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_17,								0x042B,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_18,								0x042C,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_19,								0x042D,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_20,								0x042E,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_21,								0x042F,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_22,								0x0430,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_23,								0x0431,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Device_status_24,								0x0432,		Access::R);
    modbusParamU16.emplace_back(ModbusRegister::POC_Radio_Time_sync_to_POC,								0x0433,		Access::R);

	//Radio Communication
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_1,					0x0609, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_2,					0x0616, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_3,					0x0623, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_4,					0x0630, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_5,					0x063D, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_6,					0x064A, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_7,					0x0657, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_8,					0x0664, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_9,					0x0671, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_10,					0x067E, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_11,					0x068B, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_12,					0x0698, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_13,					0x06A5, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_14,					0x06B2, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_15,					0x06BF, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_16,					0x06CC, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_17,					0x06D9, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_18,					0x06E6, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_19,					0x06F3, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_20,					0x0700, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_21,					0x070D, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_22,					0x071A, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_23,					0x0727, 8 , Access::RW);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Mac_address_device_24,					0x0734, 8 , Access::RW);
	
	//Measurement and Condition
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_Temp,											0x0C00		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_Temp_avg,										0x0C02		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_I_Phase,										0x0C04		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_I_Phase_avg,									0x0C06		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_I_Phase_max,									0x0C08		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_U_L_N,										0x0C0A		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_Freq,											0x0C0C		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_P,											0x0C0E		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_S,											0x0C10		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_Q,											0x0C12		,Access::R,		Category::Condition);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Cond_Cos_phi,										0x0C14		,Access::R,		Category::Condition);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Cond_P_in,											0x0C16		,Access::R,		Category::Condition);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Cond_P_ab,											0x0C1A		,Access::R,		Category::Condition);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Cond_S_in,											0x0C1E		,Access::R,		Category::Condition);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Cond_S_ab,											0x0C22		,Access::R,		Category::Condition);
    modbusParamU16.emplace_back(ModbusRegister::POC_Cond_Status,										0x0C26		,Access::R,		Category::Condition);

	//Measurement settings
    modbusParamU32.emplace_back(ModbusRegister::POC_Measurement_Time_period_temperature,				0x0E02		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_Activate_temp_alert,					0x0E04		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_Limit_temperature_alert,				0x0E05		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_Hysteresis_temperature_alert,			0x0E07		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_I_Averaging_interval_s,					0x0E0D		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_I_alert1_over_on_off,					0x0E0E		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert1_over_limit_percentage,		0x0E0F		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert1_over_hysteresis,				0x0E11		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_I_alert2_over_on_off,					0x0E17		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert2_over_limit_percentage,		0x0E18		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert2_over_hysteresis,				0x0E1A		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_I_alert1_under_on_off,					0x0E20		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert1_under_limit_percentage,		0x0E21		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert1_under_hysteresis,				0x0E23		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_I_alert2_under_on_off,					0x0E29		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert2_under_limit_percentage,		0x0E2A		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_I_alert2_under_hysteresis,				0x0E2C		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_U_alert1_over_on_off,					0x0E32		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert1_over_limit_percentage,		0x0E33		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert1_over_hysteresis,				0x0E35		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_U_alert2_over_on_off,					0x0E3B		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert2_over_limit_percentage,		0x0E3C		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert2_over_hysteresis,				0x0E3E		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_U_alert1_under_on_off,					0x0E44		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert1_under_limit_percentage,		0x0E45		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert1_under_hysteresis,				0x0E47		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_U_alert2_under_on_off,					0x0E4D		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert2_under_limit_percentage,		0x0E4E		,Access::RW	);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Measurement_U_alert2_under_hysteresis,				0x0E50		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_Energy_flow_direction,					0x0E5A		,Access::RW	);
    modbusParamU16.emplace_back(ModbusRegister::POC_Measurement_Alert_on_off_AFDD_threshold_shortfall,	0x0E5C		,Access::RW	);


	//Diagnosis
    modbusParamU32.emplace_back(ModbusRegister::POC_Diag_Alert,											0x0A00		,Access::R	, Category::Alert);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Diag_H_run_with_I,									0x0A02		,Access::R	, Category::Diagnosis);
    modbusParamU16.emplace_back(ModbusRegister::POC_Diag_Alert_on_off_run_total_with_I,					0x0A06		,Access::RW	, Category::Diagnosis);
    modbusParamU16.emplace_back(ModbusRegister::POC_Diag_Min_load_current,								0x0A07		,Access::RW	, Category::Diagnosis);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Diag_Limit_run_hours_with_I_alert,					0x0A08		,Access::RW	, Category::Diagnosis);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Diag_H_run_total,									0x0A12		,Access::R	, Category::Diagnosis);
    modbusParamU16.emplace_back(ModbusRegister::POC_Diag_Alert_on_off_run_total,						0x0A16		,Access::RW	, Category::Diagnosis);
    modbusParamFP64.emplace_back(ModbusRegister::POC_Diag_Limit_run_hours_total_alert,					0x0A17		,Access::RW	, Category::Diagnosis);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Diag_Nr_of_mechanical_switchings,					0x0A21		,Access::R	, Category::Diagnosis);
    modbusParamU16.emplace_back(ModbusRegister::POC_Diag_Alert_on_off_nr_mechanical_switchings,			0x0A23		,Access::RW	, Category::Diagnosis);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Diag_Limit_mechanical_switchings,					0x0A24		,Access::RW	, Category::Diagnosis);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Diag_Nr_of_triggered_switches,						0x0A2A		,Access::R	, Category::Diagnosis);
    modbusParamU16.emplace_back(ModbusRegister::POC_Diag_Alert_on_off_nr_triggered_switchings,			0x0A2C		,Access::RW	, Category::Diagnosis);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Diag_Limit_triggered_switchings,					0x0A2D		,Access::RW	, Category::Diagnosis);
    modbusParamS16.emplace_back(ModbusRegister::POC_Diag_RSSI_BLE,										0x0A3D		,Access::R	, Category::Diagnosis);
    modbusParamS16.emplace_back(ModbusRegister::POC_Diag_RSSI_radio,									0x0A3E		,Access::R	, Category::Diagnosis);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Diag_Nr_of_short_circuit_triggers,					0x0A40		,Access::R	, Category::Diagnosis);
    modbusParamU16.emplace_back(ModbusRegister::POC_Diag_Alert_on_off_nr_short_circuit_triggers,		0x0A42		,Access::RW	, Category::Diagnosis);
    modbusParamFP32.emplace_back(ModbusRegister::POC_Diag_Nr_of_short_circuit_triggers,					0x0A43		,Access::RW	, Category::Diagnosis);
    modbusParamString.emplace_back(ModbusRegister::POC_Diag_Time_and_sync_status,						0x0A45, 8   ,Access::R	, Category::Diagnosis);
	

	//Radio Communication
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_1,					0x0600, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_2,					0x060D, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_3,					0x061A, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_4,					0x0627, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_5,					0x0634, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_6,					0x0641, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_7,					0x064E, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_8,					0x065B, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_9,					0x0668, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_10,					0x0675, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_11,					0x0682, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_12,					0x068F, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_13,					0x069C, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_14,					0x06A9, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_15,					0x06B6, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_16,					0x06C3, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_17,					0x06D0, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_18,					0x06DD, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_19,					0x06EA, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_20,					0x06F7, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_21,					0x0704, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_22,					0x0711, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_23,					0x071E, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Installation_Code_24,					0x072B, 18, Access::W);
    modbusParamString.emplace_back(ModbusRegister::POC_RadioCom_Paring_Device,							0x0738, 18, Access::W);

}


